"""Disconnection Layer"""
from displayio import Group, OnDiskBitmap, TileGrid


class Disconnection:
    """Display and handle disconnection error."""
    def __init__(self, group: Group):
        """Initialize.

        :param Group group: Display IO group to contain message
        """
        # Initialize error icon for Wi-Fi or MQTT connection error
        self._group = group
        self._bmp = OnDiskBitmap("/disconnected16c.bmp")  # 24x18 4bpp
        self._grid = TileGrid(self._bmp,
                              pixel_shader=self._bmp.pixel_shader,
                              x=232, y=46)
        self._visible = False

    @property
    def visible(self) -> bool:
        """Is the disconnect error bitmap visible."""
        return self._visible

    @visible.setter
    def visible(self, show: bool) -> None:
        """Set disconnect error bitmap visibility"""
        self._visible = show
        if show:
            if self._grid not in self._group:
                self._group.append(self._grid)
        else:
            if self._grid in self._group:
                self._group.remove(self._grid)
